==> agr-center-infrastructure-3.0.0-CLOUD-20221226.112038-2-sources.jar: com/tydic/dyc/agr/repository/po/AgrPayConfigPO.java <==
package com.tydic.dyc.agr.repository.po;

import lombok.Data;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 描述：agr_pay_config
 * 
 * @author auto_gen
 * @date 2022-10-24 16:03
 **/
@Data
public class AgrPayConfigPO implements Serializable {
	private static final long serialVersionUID =  2368764427203725963L;

	/**
	 * 支付配置id
	 */
	private Long payCfgId;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 支付方
	 */
	private Integer payObj;
	/**
	 * 支付方式
	 */
	private Integer payType;
	/**
	 * 预付款
	 */
	private BigDecimal prePay;
	/**
	 * 到货款
	 */
	private BigDecimal matPay;
	/**
	 * 进度款
	 */
	private BigDecimal proPay;
	/**
	 * 验收款
	 */
	private BigDecimal verPay;
	/**
	 * 质保金
	 */
	private BigDecimal quaPay;
	/**
	 * 试运行验收款
	 */
	private BigDecimal pilPay;
	/**
	 * 是否指定日期
	 */
	private String assign;
	/**
	 * 业务节点
	 */
	private Integer busiNode;
	/**
	 * 结算月
	 */
	private String settlementMonth;
	/**
	 * 结算日
	 */
	private String settlementDate;
	/**
	 * 成交服务费比率
	 */
	private BigDecimal serviceRate;
	/**
	 * 币种
	 */
	private Integer currency;
	/**
	 * 税率
	 */
	private BigDecimal taxRate;
	/**
	 * 创建者ID
	 */
	private Long createLoginId;
	/**
	 * 创建人
	 */
	private String createName;
	/**
	 * 创建人用户名
	 */
	private String createUsername;
	/**
	 * 创建时间
	 */
	private Date createTime;
	private Date createTimeStart;
	private Date createTimeEnd;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	private Date updateTimeStart;
	private Date updateTimeEnd;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-infrastructure-3.1.1.0-CLOUD-20230415.071313-9-sources.jar: com/tydic/dyc/agr/repository/po/AgrPayConfigPO.java <==
package com.tydic.dyc.agr.repository.po;

import lombok.Data;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 描述：agr_pay_config
 * 
 * @author auto_gen
 * @date 2023-02-08 12:04
 **/
@Data
public class AgrPayConfigPO implements Serializable {
	private static final long serialVersionUID =  -4985666217579142724L;

	/**
	 * 支付配置id
	 */
	private Long payCfgId;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 支付方
	 */
	private Integer payObj;
	/**
	 * 支付方式
	 */
	private Integer payType;
	/**
	 * 预付款
	 */
	private BigDecimal prePay;
	/**
	 * 到货款
	 */
	private BigDecimal matPay;
	/**
	 * 进度款
	 */
	private BigDecimal proPay;
	/**
	 * 验收款
	 */
	private BigDecimal verPay;
	/**
	 * 质保金
	 */
	private BigDecimal quaPay;
	/**
	 * 试运行验收款
	 */
	private BigDecimal pilPay;
	/**
	 * 是否指定日期
	 */
	private String assign;
	/**
	 * 业务节点
	 */
	private Integer busiNode;
	/**
	 * 结算月
	 */
	private String settlementMonth;
	/**
	 * 结算日
	 */
	private String settlementDate;
	/**
	 * 成交服务费比率
	 */
	private BigDecimal serviceRate;
	/**
	 * 币种
	 */
	private Integer currency;
	/**
	 * 税率
	 */
	private BigDecimal taxRate;
	/**
	 * 创建者ID
	 */
	private Long createLoginId;
	/**
	 * 创建人
	 */
	private String createName;
	/**
	 * 创建人用户名
	 */
	private String createUsername;
	/**
	 * 创建时间
	 */
	private Date createTime;
	private Date createTimeStart;
	private Date createTimeEnd;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	private Date updateTimeStart;
	private Date updateTimeEnd;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 排序
	 */
	private String orderBy;

}
